@@ -11,8 +11,8 @@
 # under the License.
 
 from oslo_log import log as logging
-import six
-from six.moves.urllib import parse as urlparse
+from urllib import parse as urlparse
+import webob
 
 from senlin.api.common import util
 from senlin.api.common import wsgi
@@ -29,7 +29,7 @@ class WebhookMiddleware(wsgi.Middleware):
     """Middleware for authenticating webhook triggering requests.
 
     This middleware authenticates the webhook trigger requests and then
-    rebuild the request header so that the request will successfully pass
+    rebuilds the request header so that the request will successfully pass
     the verification of keystone auth_token middleware.
     """
     def process_request(self, req):
@@ -50,7 +50,7 @@ class WebhookMiddleware(wsgi.Middleware):
 
         obj = util.parse_request(
             'ReceiverGetRequest', req, {'identity': receiver_id})
-        rpcc = rpc.EngineClient()
+        rpcc = rpc.get_engine_client()
         receiver = rpcc.call(ctx, 'receiver_get', obj)
 
         svc_ctx = context.get_service_credentials()
@@ -69,25 +69,33 @@ class WebhookMiddleware(wsgi.Middleware):
     def _parse_url(self, url):
         """Extract receiver ID from the request URL.
 
-        Parse a URL of format: http://host:port/webhooks/id/trigger?V=1&k=v
+        Parse a URL of format: http://host:port/v1/webhooks/id/trigger?V=1&k=v
         :param url: The URL from which the request is received.
         """
         parts = urlparse.urlparse(url)
         p = parts.path.split('/')
 
-        # expected: ['', 'v1', 'webhooks', 'webhook-id', 'trigger']
-        if len(p) != 5:
-            return None
+        try:
+            index = p.index('v1')
+            p = p[(index + 1):]
+        except ValueError:
+            pass
 
-        if any((p[0] != '', p[2] != 'webhooks', p[4] != 'trigger')):
+        if len(p) != 3 or p[0] != 'webhooks' or p[2] != 'trigger':
             return None
 
+        # at this point it has been determined that the URL is a webhook
+        # trigger request
         qs = urlparse.parse_qs(parts.query)
-        if 'V' not in qs:
-            return None
-        qs.pop('V')
+        if 'V' in qs:
+            qs.pop('V')
+        else:
+            raise webob.exc.HTTPBadRequest(
+                explanation=_('V query parameter is required in webhook '
+                              'trigger URL'))
+
         params = dict((k, v[0]) for k, v in qs.items())
-        return p[3], params
+        return p[1], params
 
     def _get_token(self, **kwargs):
         """Get a valid token based on the credential provided.
@@ -97,8 +105,7 @@ class WebhookMiddleware(wsgi.Middleware):
         try:
             token = driver_base.SenlinDriver().identity.get_token(**kwargs)
         except Exception as ex:
-            LOG.exception(_('Webhook failed authentication: %s.'),
-                          six.text_type(ex))
+            LOG.exception('Webhook failed authentication: %s.', ex)
             raise exc.Forbidden()
 
         return token
