@@ -11,7 +11,7 @@
 # under the License.
 
 """
-Webhook endpoint for Senlin v1 ReST API.
+Webhook endpoint for Senlin v1 REST API.
 """
 
 from senlin.api.common import util
@@ -24,16 +24,36 @@ class WebhookController(wsgi.Controller):
 
     REQUEST_SCOPE = 'webhooks'
 
+    @wsgi.Controller.api_version("1.0", "1.9")
     @util.policy_enforce
     def trigger(self, req, webhook_id, body=None):
         if body is None:
             body = {'params': None}
 
-        body = obj_base.SenlinObject.normalize_req(
-            'WebhookTriggerRequestBody', body)
+        webhook_version = req.params.getall('V')
+        if webhook_version == ['1']:
+            body = obj_base.SenlinObject.normalize_req(
+                'WebhookTriggerRequestBody', body)
+            obj = util.parse_request(
+                'WebhookTriggerRequest', req, {'identity': webhook_id,
+                                               'body': body})
+        else:
+            # webhook version 2 and greater accept parameters other than param
+            obj = util.parse_request(
+                'WebhookTriggerRequestParamsInBody', req,
+                {'identity': webhook_id, 'body': body})
+
+        res = self.rpc_client.call(req.context, 'webhook_trigger', obj)
+        location = {'location': '/actions/%s' % res['action']}
+        res.update(location)
+        return res
+
+    @wsgi.Controller.api_version("1.10")  # noqa
+    @util.policy_enforce
+    def trigger(self, req, webhook_id, body=None):
         obj = util.parse_request(
-            'WebhookTriggerRequest', req, {'identity': webhook_id,
-                                           'body': body})
+            'WebhookTriggerRequestParamsInBody', req, {'identity': webhook_id,
+                                                       'body': body})
 
         res = self.rpc_client.call(req.context, 'webhook_trigger', obj)
         location = {'location': '/actions/%s' % res['action']}
