@@ -11,7 +11,6 @@
 # under the License.
 
 import collections
-import six
 
 from senlin.common import exception as exc
 from senlin.common.i18n import _
@@ -25,11 +24,11 @@ class BaseConstraint(collections.Mapping):
     )
 
     def __str__(self):
-        '''Utility method for generating schema docs.'''
+        """Utility method for generating schema docs."""
         return self.desc()
 
     def validate(self, value, schema=None, context=None):
-        '''Base entry for validation.'''
+        """Base entry for validation."""
         if not self._validate(value, schema=schema, context=context):
             raise ValueError(self._error(value))
 
@@ -61,7 +60,7 @@ class BaseConstraint(collections.Mapping):
 class AllowedValues(BaseConstraint):
     def __init__(self, allowed_values):
         if (not isinstance(allowed_values, collections.Sequence) or
-                isinstance(allowed_values, six.string_types)):
+                isinstance(allowed_values, str)):
             msg = _('AllowedValues must be a list or a string')
             raise exc.ESchema(message=msg)
 
