@@ -13,15 +13,15 @@
 from oslo_log import log as logging
 
 RPC_ATTRS = (
+    CONDUCTOR_TOPIC,
     ENGINE_TOPIC,
-    DISPATCHER_TOPIC,
     HEALTH_MANAGER_TOPIC,
     RPC_API_VERSION_BASE,
     RPC_API_VERSION,
 ) = (
+    'senlin-conductor',
     'senlin-engine',
-    'engine-dispatcher',
-    'engine-health-mgr',
+    'senlin-health-manager',
     '1.0',
     '1.1',
 )
@@ -138,11 +138,11 @@ CLUSTER_SORT_KEYS = [
 NODE_ATTRS = (
     NODE_INDEX, NODE_NAME, NODE_PROFILE_ID, NODE_CLUSTER_ID,
     NODE_INIT_AT, NODE_CREATED_AT, NODE_UPDATED_AT,
-    NODE_STATUS, NODE_ROLE, NODE_METADATA,
+    NODE_STATUS, NODE_ROLE, NODE_METADATA, NODE_TAINTED,
 ) = (
     'index', 'name', 'profile_id', 'cluster_id',
     'init_at', 'created_at', 'updated_at',
-    'status', 'role', 'metadata',
+    'status', 'role', 'metadata', 'tainted',
 )
 
 NODE_SORT_KEYS = [
@@ -211,13 +211,13 @@ EVENT_SORT_KEYS = [
 ]
 
 ACTION_ATTRS = (
-    ACTION_NAME, ACTION_TARGET, ACTION_ACTION, ACTION_CAUSE,
+    ACTION_NAME, ACTION_CLUSTER_ID, ACTION_TARGET, ACTION_ACTION, ACTION_CAUSE,
     ACTION_INTERVAL, ACTION_START_TIME, ACTION_END_TIME,
     ACTION_TIMEOUT, ACTION_STATUS, ACTION_STATUS_REASON,
     ACTION_INPUTS, ACTION_OUTPUTS, ACTION_DEPENDS_ON, ACTION_DEPENDED_BY,
     ACTION_CREATED_AT, ACTION_UPDATED_AT,
 ) = (
-    'name', 'target', 'action', 'cause',
+    'name', 'cluster_id', 'target', 'action', 'cause',
     'interval', 'start_time', 'end_time',
     'timeout', 'status', 'status_reason',
     'inputs', 'outputs', 'depends_on', 'depended_by',
