@@ -16,7 +16,7 @@ SQLAlchemy models for Senlin data.
 
 from oslo_db.sqlalchemy import models
 from oslo_utils import uuidutils
-from sqlalchemy import Boolean, Column, Float, ForeignKey, Integer
+from sqlalchemy import Boolean, Column, Numeric, ForeignKey, Integer
 from sqlalchemy import String, Text
 from sqlalchemy.ext import declarative
 from sqlalchemy.orm import backref
@@ -95,6 +95,8 @@ class Cluster(BASE, TimestampMixin, models.ModelBase):
     dependents = Column(types.Dict)
     config = Column(types.Dict)
 
+    profile = relationship(Profile)
+
 
 class Node(BASE, TimestampMixin, models.ModelBase):
     """Node objects."""
@@ -115,12 +117,16 @@ class Node(BASE, TimestampMixin, models.ModelBase):
 
     init_at = Column(types.TZAwareDateTime)
 
+    tainted = Column(Boolean)
     status = Column(String(255))
     status_reason = Column(Text)
     meta_data = Column(types.Dict)
     data = Column(types.Dict)
     dependents = Column(types.Dict)
     profile = relationship(Profile, backref=backref('nodes'))
+    cluster = relationship(Cluster, backref=backref('nodes'),
+                           foreign_keys=[cluster_id],
+                           primaryjoin='Cluster.id == Node.cluster_id')
 
 
 class ClusterLock(BASE, models.ModelBase):
@@ -222,15 +228,15 @@ class Action(BASE, TimestampMixin, models.ModelBase):
 
     id = Column('id', String(36), primary_key=True, default=lambda: UUID4())
     name = Column(String(63))
+    cluster_id = Column(String(36))
     context = Column(types.Dict)
     target = Column(String(36))
     action = Column(Text)
     cause = Column(String(255))
     owner = Column(String(36))
     interval = Column(Integer)
-    # FIXME: Don't specify fixed precision.
-    start_time = Column(Float(precision='24,8'))
-    end_time = Column(Float(precision='24,8'))
+    start_time = Column(Numeric(18, 6))
+    end_time = Column(Numeric(18, 6))
     timeout = Column(Integer)
     status = Column(String(255))
     status_reason = Column(Text)
@@ -242,6 +248,13 @@ class Action(BASE, TimestampMixin, models.ModelBase):
     project = Column(String(32))
     domain = Column(String(32))
 
+    dep_on = relationship(
+        ActionDependency,
+        primaryjoin="Action.id == ActionDependency.dependent")
+    dep_by = relationship(
+        ActionDependency,
+        primaryjoin="Action.id == ActionDependency.depended")
+
 
 class Event(BASE, models.ModelBase):
     """Events generated by the Senin engine."""
