@@ -11,7 +11,6 @@
 # under the License.
 
 import eventlet
-import six
 import time
 
 from oslo_config import cfg
@@ -92,6 +91,7 @@ class Action(object):
 
         self.id = kwargs.get('id', None)
         self.name = kwargs.get('name', '')
+        self.cluster_id = kwargs.get('cluster_id', '')
 
         self.context = ctx
         self.user = ctx.user_id
@@ -150,6 +150,7 @@ class Action(object):
 
         values = {
             'name': self.name,
+            'cluster_id': self.cluster_id,
             'context': self.context.to_dict(),
             'target': self.target,
             'action': self.action,
@@ -194,6 +195,7 @@ class Action(object):
         kwargs = {
             'id': obj.id,
             'name': obj.name,
+            'cluster_id': obj.cluster_id,
             'cause': obj.cause,
             'owner': obj.owner,
             'interval': obj.interval,
@@ -240,18 +242,19 @@ class Action(object):
         return cls._from_object(db_action)
 
     @classmethod
-    def create(cls, ctx, target, action, **kwargs):
+    def create(cls, ctx, target, action, force=False, **kwargs):
         """Create an action object.
 
         :param ctx: The requesting context.
         :param target: The ID of the target cluster/node.
         :param action: Name of the action.
+        :param force: Skip checking locks/conflicts
         :param dict kwargs: Other keyword arguments for the action.
         :return: ID of the action created.
         """
-
-        cls._check_action_lock(target, action)
-        cls._check_conflicting_actions(ctx, target, action)
+        if not force:
+            cls._check_action_lock(target, action)
+            cls._check_conflicting_actions(ctx, target, action)
 
         params = {
             'user_id': ctx.user_id,
@@ -624,6 +627,7 @@ class Action(object):
         action_dict = {
             'id': self.id,
             'name': self.name,
+            'cluster_id': self.cluster_id,
             'action': self.action,
             'target': self.target,
             'cause': self.cause,
@@ -676,7 +680,7 @@ def ActionProc(ctx, action_id):
         # We catch exception here to make sure the following logics are
         # executed.
         result = action.RES_ERROR
-        reason = six.text_type(ex)
+        reason = str(ex)
         LOG.exception('Unexpected exception occurred during action '
                       '%(action)s (%(id)s) execution: %(reason)s',
                       {'action': action.action, 'id': action.id,
