@@ -26,7 +26,6 @@ from senlin.engine import cluster as cluster_mod
 from senlin.engine import dispatcher
 from senlin.engine import node as node_mod
 from senlin.engine.notifications import message as msg
-from senlin.engine import scheduler
 from senlin.engine import senlin_lock
 from senlin.objects import action as ao
 from senlin.objects import cluster as co
@@ -110,7 +109,8 @@ class ClusterAction(base.Action):
                 return self.RES_LIFECYCLE_HOOK_TIMEOUT, reason
 
             # Continue waiting (with reschedule)
-            scheduler.reschedule(self.id, 3)
+            LOG.debug('Action %s sleep for 3 seconds ', self.id)
+            self._sleep(3)
             status = self.get_status()
             dispatcher.start_action()
 
@@ -168,6 +168,7 @@ class ClusterAction(base.Action):
 
             kwargs = {
                 'name': 'node_create_%s' % node.id[:8],
+                'cluster_id': self.entity.id,
                 'cause': consts.CAUSE_DERIVED,
             }
             action_id = base.Action.create(self.context, node.id,
@@ -243,6 +244,7 @@ class ClusterAction(base.Action):
             for node in nodes:
                 kwargs = {
                     'name': 'node_update_%s' % node[:8],
+                    'cluster_id': self.entity.id,
                     'cause': consts.CAUSE_DERIVED,
                     'inputs': {
                         'new_profile_id': profile_id,
@@ -349,6 +351,7 @@ class ClusterAction(base.Action):
         for node_id in node_ids:
             kwargs = {
                 'name': 'node_delete_%s' % node_id[:8],
+                'cluster_id': self.entity.id,
                 'cause': consts.CAUSE_DERIVED_LCH,
                 'inputs': inputs or {},
             }
@@ -421,6 +424,7 @@ class ClusterAction(base.Action):
         for node_id in node_ids:
             kwargs = {
                 'name': 'node_delete_%s' % node_id[:8],
+                'cluster_id': self.entity.id,
                 'cause': consts.CAUSE_DERIVED,
                 'inputs': inputs or {},
             }
@@ -536,17 +540,6 @@ class ClusterAction(base.Action):
             self.entity.eval_status(self.context, consts.CLUSTER_DELETE)
             return self.RES_ERROR, 'Cannot delete cluster object.'
 
-        # Remove all action records which target on deleted
-        # cluster except the on-going CLUSTER_DELETE action from DB
-        try:
-            ao.Action.delete_by_target(
-                self.context, self.target,
-                action_excluded=[consts.CLUSTER_DELETE],
-                status=[consts.ACTION_SUCCEEDED,
-                        consts.ACTION_FAILED])
-        except Exception as ex:
-            LOG.warning('Failed to clean cluster action records: %s',
-                        ex)
         return self.RES_OK, reason
 
     @profiler.trace('ClusterAction.do_add_nodes', hide_args=False)
@@ -594,6 +587,7 @@ class ClusterAction(base.Action):
             nid = node.id
             kwargs = {
                 'name': 'node_join_%s' % nid[:8],
+                'cluster_id': self.entity.id,
                 'cause': consts.CAUSE_DERIVED,
                 'inputs': {'cluster_id': self.target},
             }
@@ -748,6 +742,7 @@ class ClusterAction(base.Action):
         children = []
         for (original, replacement) in node_dict.items():
             kwargs = {
+                'cluster_id': self.entity.id,
                 'cause': consts.CAUSE_DERIVED,
             }
 
