@@ -22,7 +22,6 @@ from senlin.engine import cluster as cm
 from senlin.engine import event as EVENT
 from senlin.engine import node as node_mod
 from senlin.engine import senlin_lock
-from senlin.objects import action as ao
 from senlin.objects import node as no
 from senlin.policies import base as pb
 
@@ -121,16 +120,6 @@ class NodeAction(base.Action):
         if not res:
             return self.RES_ERROR, 'Node deletion failed.'
 
-        # Remove all action records which target on deleted
-        # node except the on-going NODE_DELETE action from DB
-        try:
-            ao.Action.delete_by_target(
-                self.context, self.target,
-                action_excluded=[consts.NODE_DELETE],
-                status=[consts.ACTION_SUCCEEDED, consts.ACTION_FAILED])
-        except Exception as ex:
-            LOG.warning('Failed to clean node action records: %s',
-                        ex)
         return self.RES_OK, 'Node deleted successfully.'
 
     @profiler.trace('NodeAction.do_update', hide_args=False)
