@@ -35,7 +35,8 @@ class HealthRegistry(base.SenlinObject, base.VersionedObjectDictCompat):
     def create(cls, context, cluster_id, check_type, interval, params,
                engine_id, enabled=True):
         obj = db_api.registry_create(context, cluster_id, check_type,
-                                     interval, params, engine_id,
+                                     interval,
+                                     params, engine_id,
                                      enabled=enabled)
         return cls._from_db_object(context, cls(), obj)
 
@@ -56,3 +57,20 @@ class HealthRegistry(base.SenlinObject, base.VersionedObjectDictCompat):
     def get(cls, context, cluster_id):
         obj = db_api.registry_get(context, cluster_id)
         return cls._from_db_object(context, cls(), obj)
+
+    @classmethod
+    def get_by_engine(cls, context, engine_id, cluster_id):
+        params = {
+            "cluster_id": cluster_id,
+            "engine_id": engine_id,
+        }
+        obj = db_api.registry_get_by_param(context, params)
+        return cls._from_db_object(context, cls(), obj)
+
+    @classmethod
+    def disable_registry(cls, context, cluster_id):
+        cls.update(context, cluster_id, {'enabled': False})
+
+    @classmethod
+    def enable_registry(cls, context, cluster_id):
+        cls.update(context, cluster_id, {"enabled": True})
