@@ -10,8 +10,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import copy
 import mock
-import six
 from webob import exc
 
 from oslo_serialization import jsonutils
@@ -50,6 +50,7 @@ class ActionControllerTest(shared.ControllerTest, base.SenlinTestCase):
             {
                 'action': 'NODE_CREATE',
                 'cause': 'RPC_Request',
+                'cluster_id': 'CLUSTER_FAKE_ID',
                 'depended_by': [],
                 'depends_on': [],
                 'end_time': 1425555000.0,
@@ -79,6 +80,92 @@ class ActionControllerTest(shared.ControllerTest, base.SenlinTestCase):
         mock_call.assert_called_once_with(
             req.context, 'action_list', obj)
 
+    @mock.patch.object(util, 'parse_request')
+    @mock.patch.object(rpc_client.EngineClient, 'call')
+    def test_action_index_without_cluster_id(self, mock_call, mock_parse,
+                                             mock_enforce):
+        self._mock_enforce_setup(mock_enforce, 'index', True)
+        req = self._get('/actions', version='1.13')
+
+        engine_resp = [
+            {
+                'action': 'NODE_CREATE',
+                'cause': 'RPC_Request',
+                'cluster_id': 'CLUSTER_FAKE_ID',
+                'depended_by': [],
+                'depends_on': [],
+                'end_time': 1425555000.0,
+                'id': '2366d400-c7e3-4961-09254-6d1c3f7ac167',
+                'inputs': {},
+                'interval': -1,
+                'name': 'node_create_0df0931b',
+                'outputs': {},
+                'owner': None,
+                'start_time': 1425550000.0,
+                'status': 'SUCCEEDED',
+                'status_reason': 'Action completed successfully.',
+                'target': '0df0931b-e251-4f2e-8719-4effda3627ba',
+                'timeout': 3600
+            }
+        ]
+
+        mock_call.return_value = copy.deepcopy(engine_resp)
+        obj = mock.Mock()
+        mock_parse.return_value = obj
+
+        result = self.controller.index(req)
+
+        # list call for version < 1.14 should have cluster_id field removed
+        # remove cluster_id field from expected response
+        engine_resp[0].pop('cluster_id')
+
+        self.assertEqual(engine_resp, result['actions'])
+        mock_parse.assert_called_once_with(
+            'ActionListRequest', req, {'project_safe': True})
+        mock_call.assert_called_once_with(
+            req.context, 'action_list', obj)
+
+    @mock.patch.object(util, 'parse_request')
+    @mock.patch.object(rpc_client.EngineClient, 'call')
+    def test_action_index_with_cluster_id(self, mock_call, mock_parse,
+                                          mock_enforce):
+        self._mock_enforce_setup(mock_enforce, 'index', True)
+        req = self._get('/actions', version='1.14')
+
+        engine_resp = [
+            {
+                'action': 'NODE_CREATE',
+                'cause': 'RPC_Request',
+                'cluster_id': 'CLUSTER_FAKE_ID',
+                'depended_by': [],
+                'depends_on': [],
+                'end_time': 1425555000.0,
+                'id': '2366d400-c7e3-4961-09254-6d1c3f7ac167',
+                'inputs': {},
+                'interval': -1,
+                'name': 'node_create_0df0931b',
+                'outputs': {},
+                'owner': None,
+                'start_time': 1425550000.0,
+                'status': 'SUCCEEDED',
+                'status_reason': 'Action completed successfully.',
+                'target': '0df0931b-e251-4f2e-8719-4effda3627ba',
+                'timeout': 3600
+            }
+        ]
+
+        mock_call.return_value = copy.deepcopy(engine_resp)
+        obj = mock.Mock()
+        mock_parse.return_value = obj
+
+        result = self.controller.index(req)
+
+        self.assertEqual(engine_resp, result['actions'])
+        mock_parse.assert_called_once_with(
+            'ActionListRequest', req, {'project_safe': True})
+        mock_call.assert_called_once_with(
+            req.context, 'action_list', obj)
+
     @mock.patch.object(util, 'parse_request')
     @mock.patch.object(rpc_client.EngineClient, 'call')
     def test_action_index_whitelists_params(self, mock_call,
@@ -86,6 +173,7 @@ class ActionControllerTest(shared.ControllerTest, base.SenlinTestCase):
         self._mock_enforce_setup(mock_enforce, 'index', True)
         marker_uuid = '8216a86c-1bdc-442e-b493-329385d37cbc'
         params = {
+            'cluster_id': 'CLUSTER_FAKE_ID',
             'name': 'NODE_CREATE',
             'status': 'SUCCEEDED',
             'limit': 10,
@@ -105,6 +193,7 @@ class ActionControllerTest(shared.ControllerTest, base.SenlinTestCase):
         mock_parse.assert_called_once_with(
             'ActionListRequest', req,
             {
+                'cluster_id': ['CLUSTER_FAKE_ID'],
                 'status': ['SUCCEEDED'],
                 'sort': 'status',
                 'name': ['NODE_CREATE'],
@@ -146,7 +235,7 @@ class ActionControllerTest(shared.ControllerTest, base.SenlinTestCase):
                                self.controller.index,
                                req)
 
-        self.assertEqual("bad param", six.text_type(ex))
+        self.assertEqual("bad param", str(ex))
         mock_parse.assert_called_once_with(
             'ActionListRequest', req, mock.ANY)
         self.assertFalse(mock_call.called)
@@ -163,7 +252,7 @@ class ActionControllerTest(shared.ControllerTest, base.SenlinTestCase):
         ex = self.assertRaises(exc.HTTPBadRequest,
                                self.controller.index, req)
 
-        self.assertEqual("bad limit", six.text_type(ex))
+        self.assertEqual("bad limit", str(ex))
         mock_parse.assert_called_once_with(
             'ActionListRequest', req, mock.ANY)
         self.assertFalse(mock_call.called)
@@ -223,7 +312,7 @@ class ActionControllerTest(shared.ControllerTest, base.SenlinTestCase):
                                self.controller.index, req)
 
         self.assertEqual("Invalid value 'No' specified for 'global_project'",
-                         six.text_type(ex))
+                         str(ex))
         self.assertFalse(mock_call.called)
         self.assertFalse(mock_parse.called)
 
@@ -235,7 +324,7 @@ class ActionControllerTest(shared.ControllerTest, base.SenlinTestCase):
                                               self.controller.index,
                                               req)
         self.assertEqual(403, resp.status_int)
-        self.assertIn('403 Forbidden', six.text_type(resp))
+        self.assertIn('403 Forbidden', str(resp))
 
     @mock.patch.object(util, 'parse_request')
     @mock.patch.object(rpc_client.EngineClient, 'call')
@@ -247,6 +336,7 @@ class ActionControllerTest(shared.ControllerTest, base.SenlinTestCase):
         engine_resp = {
             'action': 'NODE_CREATE',
             'cause': 'RPC_Request',
+            'cluster_id': 'CLUSTER_FAKE_ID',
             'depended_by': [],
             'depends_on': [],
             'end_time': 1425555000.0,
@@ -310,7 +400,7 @@ class ActionControllerTest(shared.ControllerTest, base.SenlinTestCase):
                                               req, action_id=action_id)
 
         self.assertEqual(403, resp.status_int)
-        self.assertIn('403 Forbidden', six.text_type(resp))
+        self.assertIn('403 Forbidden', str(resp))
 
     @mock.patch.object(util, 'parse_request')
     @mock.patch.object(rpc_client.EngineClient, 'call')
@@ -389,7 +479,7 @@ class ActionControllerTest(shared.ControllerTest, base.SenlinTestCase):
                                action_id=aid, body=body)
 
         self.assertEqual("Malformed request data, missing 'action' key "
-                         "in request body.", six.text_type(ex))
+                         "in request body.", str(ex))
 
         self.assertFalse(mock_parse.called)
         self.assertFalse(mock_call.called)
