@@ -81,7 +81,9 @@ class DBAPIClusterTest(base.SenlinTestCase):
                                         is_admin=True)
         ret_cluster = db_api.cluster_get(admin_ctx, cluster.id,
                                          project_safe=True)
-        self.assertIsNone(ret_cluster)
+        self.assertEqual(cluster.id, ret_cluster.id)
+        self.assertEqual('db_test_cluster_name', ret_cluster.name)
+
         ret_cluster = db_api.cluster_get(admin_ctx, cluster.id,
                                          project_safe=False)
         self.assertEqual(cluster.id, ret_cluster.id)
@@ -100,6 +102,7 @@ class DBAPIClusterTest(base.SenlinTestCase):
         self.assertIsNone(db_api.cluster_get_by_name(self.ctx, cluster.name))
 
     def test_cluster_get_by_name_diff_project(self):
+        self.ctx.project_id = UUID2
         cluster1 = shared.create_cluster(self.ctx, self.profile,
                                          name='cluster_A',
                                          project=UUID2)
@@ -109,6 +112,7 @@ class DBAPIClusterTest(base.SenlinTestCase):
         shared.create_cluster(self.ctx, self.profile, name='cluster_B',
                               project=UUID2)
 
+        self.ctx.project_id = UUID1
         res = db_api.cluster_get_by_name(self.ctx, 'cluster_A')
         self.assertIsNone(res)
 
@@ -226,7 +230,8 @@ class DBAPIClusterTest(base.SenlinTestCase):
         admin_ctx = utils.dummy_context(project='another-project',
                                         is_admin=True)
         clusters = db_api.cluster_get_all(admin_ctx, project_safe=True)
-        self.assertEqual(0, len(clusters))
+        self.assertEqual(5, len(clusters))
+
         clusters = db_api.cluster_get_all(admin_ctx, project_safe=False)
         self.assertEqual(5, len(clusters))
 
@@ -370,7 +375,7 @@ class DBAPIClusterTest(base.SenlinTestCase):
 
         admin_ctx = utils.dummy_context(project='another-project',
                                         is_admin=True)
-        self.assertEqual(0, db_api.cluster_count_all(admin_ctx,
+        self.assertEqual(5, db_api.cluster_count_all(admin_ctx,
                                                      project_safe=True))
         self.assertEqual(5, db_api.cluster_count_all(admin_ctx,
                                                      project_safe=False))
