@@ -12,8 +12,10 @@
 
 import mock
 
-from senlin.drivers.openstack import sdk
-from senlin.drivers.openstack import zaqar_v2
+from openstack import exceptions as sdk_exc
+
+from senlin.drivers.os import zaqar_v2
+from senlin.drivers import sdk
 from senlin.tests.unit.common import base
 from senlin.tests.unit.common import utils
 
@@ -41,6 +43,21 @@ class TestZaqarV2(base.SenlinTestCase):
         zc.queue_create(name='foo')
         self.message.create_queue.assert_called_once_with(name='foo')
 
+    def test_queue_exists(self):
+        zc = zaqar_v2.ZaqarClient(self.conn_params)
+        res = zc.queue_exists('foo')
+        self.message.get_queue.assert_called_once_with('foo')
+        self.assertTrue(res)
+
+    def test_queue_exists_false(self):
+        zc = zaqar_v2.ZaqarClient(self.conn_params)
+        self.message.get_queue = mock.Mock()
+        self.message.get_queue.side_effect = sdk_exc.ResourceNotFound
+
+        res = zc.queue_exists('foo')
+        self.message.get_queue.assert_called_once_with('foo')
+        self.assertFalse(res)
+
     def test_queue_delete(self):
         zc = zaqar_v2.ZaqarClient(self.conn_params)
         zc.queue_delete('foo', True)
@@ -121,3 +138,8 @@ class TestZaqarV2(base.SenlinTestCase):
         zc.message_delete('foo', 'MESSAGE_ID', 'CLAIM_ID')
         self.message.delete_message.assert_called_once_with(
             'foo', 'MESSAGE_ID', 'CLAIM_ID', True)
+
+    def test_message_post(self):
+        zc = zaqar_v2.ZaqarClient(self.conn_params)
+        zc.message_post('foo', 'MESSAGE')
+        self.message.post_message.assert_called_once_with('foo', 'MESSAGE')
