@@ -17,7 +17,6 @@ import mock
 from oslo_config import cfg
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
-import six
 
 from senlin.common import consts
 from senlin.common import exception
@@ -62,6 +61,7 @@ class ActionBaseTest(base.SenlinTestCase):
         self.ctx = utils.dummy_context(project=PROJECT_ID, user_id=USER_ID)
         self.action_values = {
             'name': 'FAKE_NAME',
+            'cluster_id': 'FAKE_CLUSTER_ID',
             'cause': 'FAKE_CAUSE',
             'owner': OWNER_ID,
             'interval': 60,
@@ -80,6 +80,7 @@ class ActionBaseTest(base.SenlinTestCase):
     def _verify_new_action(self, obj, target, action):
         self.assertIsNone(obj.id)
         self.assertEqual('', obj.name)
+        self.assertEqual('', obj.cluster_id)
         self.assertEqual(target, obj.target)
         self.assertEqual(action, obj.action)
         self.assertEqual('', obj.cause)
@@ -123,6 +124,7 @@ class ActionBaseTest(base.SenlinTestCase):
 
         self.assertEqual('FAKE_ID', obj.id)
         self.assertEqual('FAKE_NAME', obj.name)
+        self.assertEqual('FAKE_CLUSTER_ID', obj.cluster_id)
         self.assertEqual(OBJID, obj.target)
         self.assertEqual('FAKE_CAUSE', obj.cause)
         self.assertEqual(OWNER_ID, obj.owner)
@@ -180,6 +182,7 @@ class ActionBaseTest(base.SenlinTestCase):
         action_obj = ab.Action._from_object(record)
         self.assertIsInstance(action_obj, ab.Action)
         self.assertEqual(obj.id, action_obj.id)
+        self.assertEqual(obj.cluster_id, action_obj.cluster_id)
         self.assertEqual(obj.action, action_obj.action)
         self.assertEqual(obj.name, action_obj.name)
         self.assertEqual(obj.target, action_obj.target)
@@ -234,7 +237,7 @@ class ActionBaseTest(base.SenlinTestCase):
                                ab.Action.load,
                                self.ctx, 'non-existent', None)
         self.assertEqual("The action 'non-existent' could not be "
-                         "found.", six.text_type(ex))
+                         "found.", str(ex))
 
         # not found due to no object
         self.patchobject(ao.Action, 'get', return_value=None)
@@ -242,7 +245,7 @@ class ActionBaseTest(base.SenlinTestCase):
                                ab.Action.load,
                                self.ctx, 'whatever', None)
         self.assertEqual("The action 'whatever' could not be found.",
-                         six.text_type(ex))
+                         str(ex))
 
     @mock.patch.object(ab.Action, 'store')
     def test_action_create(self, mock_store):
@@ -931,6 +934,7 @@ class ActionBaseTest(base.SenlinTestCase):
         expected = {
             'id': 'FAKE_ID',
             'name': 'FAKE_NAME',
+            'cluster_id': 'FAKE_CLUSTER_ID',
             'action': 'OBJECT_ACTION',
             'target': OBJID,
             'cause': 'FAKE_CAUSE',
