@@ -19,6 +19,7 @@ from senlin.engine.actions import cluster_action as ca
 from senlin.engine import cluster as cm
 from senlin.engine import dispatcher
 from senlin.engine import senlin_lock
+from senlin.objects import action as ao
 from senlin.policies import base as pb
 from senlin.tests.unit.common import base
 from senlin.tests.unit.common import utils
@@ -36,7 +37,7 @@ class ClusterActionTest(base.SenlinTestCase):
         self.ctx = utils.dummy_context()
 
     @mock.patch.object(ab.Action, 'policy_check')
-    def test__execute(self, mock_check, mock_load):
+    def test_execute(self, mock_check, mock_load):
         cluster = mock.Mock()
         cluster.id = 'FAKE_CLUSTER'
         mock_load.return_value = cluster
@@ -55,6 +56,26 @@ class ClusterActionTest(base.SenlinTestCase):
             mock.call('FAKE_CLUSTER', 'BEFORE'),
             mock.call('FAKE_CLUSTER', 'AFTER')])
 
+    @mock.patch.object(ab.Action, 'policy_check')
+    def test_execute_failed_action(self, mock_check, mock_load):
+        cluster = mock.Mock()
+        cluster.id = 'FAKE_CLUSTER'
+        mock_load.return_value = cluster
+        action = ca.ClusterAction(cluster.id, 'CLUSTER_FLY', self.ctx)
+        action.do_fly = mock.Mock(return_value=(action.RES_ERROR, 'Good!'))
+        action.data = {
+            'status': pb.CHECK_OK,
+            'reason': 'Policy checking passed'
+        }
+
+        res_code, res_msg = action._execute()
+
+        self.assertEqual(action.RES_ERROR, res_code)
+        self.assertEqual('Good!', res_msg)
+        mock_check.assert_has_calls([
+            mock.call('FAKE_CLUSTER', 'BEFORE'),
+            mock.call('FAKE_CLUSTER', 'AFTER')])
+
     @mock.patch.object(ab.Action, 'policy_check')
     def test_execute_failed_policy_check(self, mock_check, mock_load):
         cluster = mock.Mock()
@@ -122,7 +143,7 @@ class ClusterActionTest(base.SenlinTestCase):
 
     @mock.patch.object(senlin_lock, 'cluster_lock_acquire')
     @mock.patch.object(senlin_lock, 'cluster_lock_release')
-    def test_execute(self, mock_release, mock_acquire, mock_load):
+    def test_execute_with_locking(self, mock_release, mock_acquire, mock_load):
         cluster = mock.Mock()
         cluster.id = 'FAKE_CLUSTER'
         mock_load.return_value = cluster
@@ -200,7 +221,8 @@ class CompleteLifecycleProcTest(base.SenlinTestCase):
 
     @mock.patch.object(dispatcher, 'start_action')
     @mock.patch.object(ab.Action, 'load')
-    def test_complete_lifecycle_proc_successful(self, mock_load,
+    @mock.patch.object(ao.Action, 'update')
+    def test_complete_lifecycle_proc_successful(self, mock_update, mock_load,
                                                 mock_dispatcher_start):
         action = ab.Action(OBJID, 'OBJECT_ACTION', self.ctx)
         mock_obj = mock.Mock()
@@ -208,7 +230,6 @@ class CompleteLifecycleProcTest(base.SenlinTestCase):
         mock_get_status = self.patchobject(action, 'get_status')
         mock_get_status.return_value = \
             consts.ACTION_WAITING_LIFECYCLE_COMPLETION
-        mock_set_status = self.patchobject(action, 'set_status')
         mock_load.return_value = action
 
         res = ca.CompleteLifecycleProc(self.ctx, 'ACTION_ID')
@@ -217,7 +238,12 @@ class CompleteLifecycleProcTest(base.SenlinTestCase):
         mock_load.assert_called_once_with(self.ctx, action_id='ACTION_ID',
                                           project_safe=False)
         mock_get_status.assert_called_once_with()
-        mock_set_status.assert_called_once_with(action.RES_LIFECYCLE_COMPLETE)
+        mock_update.assert_called_once_with(
+            self.ctx, 'ACTION_ID',
+            {'status': consts.ACTION_READY,
+             'status_reason': 'Lifecycle complete.',
+             'owner': None}
+        )
         mock_dispatcher_start.assert_called_once_with()
 
     @mock.patch.object(ab.Action, 'load')
@@ -230,14 +256,14 @@ class CompleteLifecycleProcTest(base.SenlinTestCase):
 
     @mock.patch.object(dispatcher, 'start_action')
     @mock.patch.object(ab.Action, 'load')
-    def test_complete_lifecycle_proc_warning(self, mock_load,
+    @mock.patch.object(ao.Action, 'update')
+    def test_complete_lifecycle_proc_warning(self, mock_update, mock_load,
                                              mock_dispatcher_start):
         action = ab.Action(OBJID, 'OBJECT_ACTION', self.ctx)
         mock_obj = mock.Mock()
         action.entity = mock_obj
         mock_get_status = self.patchobject(action, 'get_status')
         mock_get_status.return_value = consts.ACTION_SUCCEEDED
-        mock_set_status = self.patchobject(action, 'set_status')
         mock_load.return_value = action
 
         res = ca.CompleteLifecycleProc(self.ctx, 'ACTION_ID')
@@ -246,5 +272,5 @@ class CompleteLifecycleProcTest(base.SenlinTestCase):
         mock_load.assert_called_once_with(self.ctx, action_id='ACTION_ID',
                                           project_safe=False)
         mock_get_status.assert_called_once_with()
-        mock_set_status.assert_not_called()
+        mock_update.assert_not_called()
         mock_dispatcher_start.assert_not_called()
