@@ -12,7 +12,6 @@
 
 import mock
 from oslo_config import cfg
-import six
 
 from senlin.common import consts
 from senlin.common import exception
@@ -87,8 +86,8 @@ class TestCluster(base.SenlinTestCase):
     @mock.patch.object(pcb.Policy, 'load')
     @mock.patch.object(pfb.Profile, 'load')
     @mock.patch.object(no.Node, 'get_all_by_cluster')
-    def test__load_runtime_data(self, mock_nodes, mock_profile, mock_policy,
-                                mock_pb):
+    def test_load_runtime_data(self, mock_nodes, mock_profile, mock_policy,
+                               mock_pb):
         x_binding = mock.Mock()
         x_binding.policy_id = POLICY_ID
         mock_pb.return_value = [x_binding]
@@ -121,7 +120,7 @@ class TestCluster(base.SenlinTestCase):
                                              project_safe=False)
         mock_nodes.assert_called_once_with(self.context, CLUSTER_ID)
 
-    def test__load_runtime_data_id_is_none(self):
+    def test_load_runtime_data_id_is_none(self):
         cluster = cm.Cluster('test-cluster', 0, PROFILE_ID)
 
         cluster._load_runtime_data(self.context)
@@ -134,6 +133,7 @@ class TestCluster(base.SenlinTestCase):
         self.assertEqual([], rt['policies'])
 
     def test_store_for_create(self):
+        utils.create_profile(self.context, PROFILE_ID)
         cluster = cm.Cluster('test-cluster', 0, PROFILE_ID,
                              user=self.context.user_id,
                              project=self.context.project_id)
@@ -168,6 +168,7 @@ class TestCluster(base.SenlinTestCase):
         self.assertEqual({}, result.metadata)
 
     def test_store_for_update(self):
+        utils.create_profile(self.context, PROFILE_ID)
         cluster = cm.Cluster('test-cluster', 0, PROFILE_ID,
                              user=self.context.user_id,
                              project=self.context.project_id)
@@ -238,7 +239,7 @@ class TestCluster(base.SenlinTestCase):
                                cm.Cluster.load,
                                self.context, cluster_id=CLUSTER_ID)
         self.assertEqual("The cluster '%s' could not be found." % CLUSTER_ID,
-                         six.text_type(ex))
+                         str(ex))
         mock_get.assert_called_once_with(self.context, CLUSTER_ID,
                                          project_safe=True)
 
@@ -534,7 +535,7 @@ class TestCluster(base.SenlinTestCase):
         mock_cp.return_value = binding
 
         values = {'enabled': True}
-        res, reason = cluster.attach_policy(self.context, POLICY_ID, values)
+        cluster.attach_policy(self.context, POLICY_ID, values)
         policy.attach.assert_called_once_with(cluster, enabled=True)
         mock_load.assert_called_once_with(self.context, POLICY_ID)
         mock_cp.assert_called_once_with(CLUSTER_ID, POLICY_ID, priority=10,
