@@ -12,7 +12,6 @@
 
 import glob
 import mock
-import six
 
 from senlin.common import exception
 from senlin.engine import environment
@@ -109,7 +108,7 @@ class TestEnvironment(base.SenlinTestCase):
         env_str = "variables:\n  p1: v1"
         err = self.assertRaises(ValueError, env.parse, env_str)
         self.assertEqual('environment has unknown section "variables"',
-                         six.text_type(err))
+                         str(err))
 
         # omitted sections
         env_str = "parameters:\n  p1: v1"
@@ -157,18 +156,18 @@ class TestEnvironment(base.SenlinTestCase):
             ex = self.assertRaises(exception.InvalidPlugin,
                                    env._check_plugin_name, pt, '')
             self.assertEqual('%s type name not specified' % pt,
-                             six.text_type(ex))
+                             str(ex))
 
             ex = self.assertRaises(exception.InvalidPlugin,
                                    env._check_plugin_name, pt, None)
             self.assertEqual('%s type name not specified' % pt,
-                             six.text_type(ex))
+                             str(ex))
 
             for v in [123, {}, ['a'], ('b', 'c'), True]:
                 ex = self.assertRaises(exception.InvalidPlugin,
                                        env._check_plugin_name, pt, v)
             self.assertEqual('%s type name is not a string' % pt,
-                             six.text_type(ex))
+                             str(ex))
 
     def test_register_and_get_profile(self):
         plugin = mock.Mock()
@@ -177,24 +176,24 @@ class TestEnvironment(base.SenlinTestCase):
         ex = self.assertRaises(exception.ResourceNotFound,
                                env.get_profile, 'foo')
         self.assertEqual("The profile_type 'foo' could not be found.",
-                         six.text_type(ex))
+                         str(ex))
 
         env.register_profile('foo', plugin)
         self.assertEqual(plugin, env.get_profile('foo'))
 
     def test_get_profile_types(self):
         env = environment.Environment()
-        plugin1 = mock.Mock(VERSIONS={'k': 'v'})
+        plugin1 = mock.Mock(VERSIONS={'1.0': 'v'})
         env.register_profile('foo-1.0', plugin1)
-        plugin2 = mock.Mock(VERSIONS={'k': 'v1'})
+        plugin2 = mock.Mock(VERSIONS={'1.2': 'v1'})
         env.register_profile('bar-1.2', plugin2)
 
         actual = env.get_profile_types()
         self.assertIn(
-            {'name': 'foo', 'version': '1.0', 'support_status': {'k': 'v'}},
+            {'name': 'foo', 'version': '1.0', 'support_status': {'1.0': 'v'}},
             actual)
         self.assertIn(
-            {'name': 'bar', 'version': '1.2', 'support_status': {'k': 'v1'}},
+            {'name': 'bar', 'version': '1.2', 'support_status': {'1.2': 'v1'}},
             actual)
 
     def test_register_and_get_policy(self):
@@ -204,24 +203,24 @@ class TestEnvironment(base.SenlinTestCase):
         ex = self.assertRaises(exception.ResourceNotFound,
                                env.get_policy, 'foo')
         self.assertEqual("The policy_type 'foo' could not be found.",
-                         six.text_type(ex))
+                         str(ex))
 
         env.register_policy('foo', plugin)
         self.assertEqual(plugin, env.get_policy('foo'))
 
     def test_get_policy_types(self):
         env = environment.Environment()
-        plugin1 = mock.Mock(VERSIONS={'k': 'v'})
+        plugin1 = mock.Mock(VERSIONS={'0.1': 'v'})
         env.register_policy('foo-0.1', plugin1)
-        plugin2 = mock.Mock(VERSIONS={'k': 'v1'})
-        env.register_policy('bar-0.2', plugin2)
+        plugin2 = mock.Mock(VERSIONS={'0.1': 'v1'})
+        env.register_policy('bar-0.1', plugin2)
 
         actual = env.get_policy_types()
         self.assertIn(
-            {'name': 'foo', 'version': '0.1', 'support_status': {'k': 'v'}},
+            {'name': 'foo', 'version': '0.1', 'support_status': {'0.1': 'v'}},
             actual)
         self.assertIn(
-            {'name': 'bar', 'version': '0.2', 'support_status': {'k': 'v1'}},
+            {'name': 'bar', 'version': '0.1', 'support_status': {'0.1': 'v1'}},
             actual)
 
     def test_register_and_get_driver_types(self):
@@ -231,7 +230,7 @@ class TestEnvironment(base.SenlinTestCase):
         ex = self.assertRaises(exception.InvalidPlugin,
                                env.get_driver, 'foo')
         self.assertEqual('Driver plugin foo is not found.',
-                         six.text_type(ex))
+                         str(ex))
 
         env.register_driver('foo', plugin)
         self.assertEqual(plugin, env.get_driver('foo'))
@@ -245,10 +244,10 @@ class TestEnvironment(base.SenlinTestCase):
 
         actual = env.get_driver_types()
         self.assertIn(
-            {'name': 'foo', 'version': '', 'support_status': {}},
+            {'name': 'foo', 'version': '', 'support_status': {'': ''}},
             actual)
         self.assertIn(
-            {'name': 'bar', 'version': '', 'support_status': {}},
+            {'name': 'bar', 'version': '', 'support_status': {'': ''}},
             actual)
 
     def test_register_and_get_endpoints(self):
@@ -258,7 +257,7 @@ class TestEnvironment(base.SenlinTestCase):
         ex = self.assertRaises(exception.InvalidPlugin,
                                env.get_endpoint, 'foo')
         self.assertEqual('Endpoint plugin foo is not found.',
-                         six.text_type(ex))
+                         str(ex))
 
         env.register_endpoint('foo', plugin)
         self.assertEqual(plugin, env.get_endpoint('foo'))
