@@ -20,13 +20,12 @@ from oslo_utils import timeutils as tu
 from senlin.common import consts
 from senlin.common import context
 from senlin.common import exception as exc
-from senlin.common import messaging
 from senlin.common import utils
 from senlin.engine import health_manager as hm
 from senlin.engine import node as node_mod
+from senlin.engine.notifications import nova_endpoint
 from senlin import objects
 from senlin.objects import cluster as obj_cluster
-from senlin.objects import health_registry as hr
 from senlin.objects import node as obj_node
 from senlin.objects import profile as obj_profile
 from senlin.rpc import client as rpc_client
@@ -38,7 +37,7 @@ class TestChaseUp(base.SenlinTestCase):
     def test_less_than_one_interval(self):
         start = tu.utcnow(True)
         # we assume that the delay before next line is < 5 seconds
-        res = hm._chase_up(start, 5)
+        res = hm.chase_up(start, 5)
 
         self.assertLessEqual(res, 5)
 
@@ -47,7 +46,7 @@ class TestChaseUp(base.SenlinTestCase):
         time.sleep(2)
 
         # we assume that the delay before next line is < 5 seconds
-        res = hm._chase_up(start, 1)
+        res = hm.chase_up(start, 1)
 
         self.assertLessEqual(res, 1)
 
@@ -55,7 +54,7 @@ class TestChaseUp(base.SenlinTestCase):
 @mock.patch('oslo_messaging.NotificationFilter')
 class TestNovaNotificationEndpoint(base.SenlinTestCase):
 
-    @mock.patch('senlin.rpc.client.EngineClient')
+    @mock.patch('senlin.rpc.client.get_engine_client')
     def test_init(self, mock_rpc, mock_filter):
         x_filter = mock_filter.return_value
         event_map = {
@@ -66,28 +65,31 @@ class TestNovaNotificationEndpoint(base.SenlinTestCase):
             'compute.instance.soft_delete.end': 'SOFT_DELETE',
         }
         recover_action = {'operation': 'REBUILD'}
-        obj = hm.NovaNotificationEndpoint('PROJECT', 'CLUSTER', recover_action)
+        endpoint = nova_endpoint.NovaNotificationEndpoint(
+            'PROJECT', 'CLUSTER_ID', recover_action
+        )
 
         mock_filter.assert_called_once_with(
             publisher_id='^compute.*',
             event_type='^compute\.instance\..*',
             context={'project_id': '^PROJECT$'})
         mock_rpc.assert_called_once_with()
-        self.assertEqual(x_filter, obj.filter_rule)
-        self.assertEqual(mock_rpc.return_value, obj.rpc)
+        self.assertEqual(x_filter, endpoint.filter_rule)
+        self.assertEqual(mock_rpc.return_value, endpoint.rpc)
         for e in event_map:
-            self.assertIn(e, obj.VM_FAILURE_EVENTS)
-            self.assertEqual(event_map[e], obj.VM_FAILURE_EVENTS[e])
-        self.assertEqual('PROJECT', obj.project_id)
-        self.assertEqual('CLUSTER', obj.cluster_id)
+            self.assertIn(e, endpoint.VM_FAILURE_EVENTS)
+            self.assertEqual(event_map[e], endpoint.VM_FAILURE_EVENTS[e])
+        self.assertEqual('PROJECT', endpoint.project_id)
+        self.assertEqual('CLUSTER_ID', endpoint.cluster_id)
 
     @mock.patch.object(context.RequestContext, 'from_dict')
-    @mock.patch('senlin.rpc.client.EngineClient')
+    @mock.patch('senlin.rpc.client.get_engine_client')
     def test_info(self, mock_rpc, mock_context, mock_filter):
         x_rpc = mock_rpc.return_value
         recover_action = {'operation': 'REBUILD'}
-        endpoint = hm.NovaNotificationEndpoint('PROJECT', 'CLUSTER_ID',
-                                               recover_action)
+        endpoint = nova_endpoint.NovaNotificationEndpoint(
+            'PROJECT', 'CLUSTER_ID', recover_action
+        )
         ctx = mock.Mock()
         payload = {
             'metadata': {
@@ -121,12 +123,13 @@ class TestNovaNotificationEndpoint(base.SenlinTestCase):
         }
         self.assertEqual(expected_params, req.params)
 
-    @mock.patch('senlin.rpc.client.EngineClient')
+    @mock.patch('senlin.rpc.client.get_engine_client')
     def test_info_no_metadata(self, mock_rpc, mock_filter):
         x_rpc = mock_rpc.return_value
         recover_action = {'operation': 'REBUILD'}
-        endpoint = hm.NovaNotificationEndpoint('PROJECT', 'CLUSTER_ID',
-                                               recover_action)
+        endpoint = nova_endpoint.NovaNotificationEndpoint(
+            'PROJECT', 'CLUSTER_ID', recover_action
+        )
         ctx = mock.Mock()
         payload = {'metadata': {}}
         metadata = {'timestamp': 'TIMESTAMP'}
@@ -137,12 +140,13 @@ class TestNovaNotificationEndpoint(base.SenlinTestCase):
         self.assertIsNone(res)
         self.assertEqual(0, x_rpc.node_recover.call_count)
 
-    @mock.patch('senlin.rpc.client.EngineClient')
+    @mock.patch('senlin.rpc.client.get_engine_client')
     def test_info_no_cluster_in_metadata(self, mock_rpc, mock_filter):
         x_rpc = mock_rpc.return_value
         recover_action = {'operation': 'REBUILD'}
-        endpoint = hm.NovaNotificationEndpoint('PROJECT', 'CLUSTER_ID',
-                                               recover_action)
+        endpoint = nova_endpoint.NovaNotificationEndpoint(
+            'PROJECT', 'CLUSTER_ID', recover_action
+        )
         ctx = mock.Mock()
         payload = {'metadata': {'foo': 'bar'}}
         metadata = {'timestamp': 'TIMESTAMP'}
@@ -153,12 +157,13 @@ class TestNovaNotificationEndpoint(base.SenlinTestCase):
         self.assertIsNone(res)
         self.assertEqual(0, x_rpc.node_recover.call_count)
 
-    @mock.patch('senlin.rpc.client.EngineClient')
+    @mock.patch('senlin.rpc.client.get_engine_client')
     def test_info_cluster_id_not_match(self, mock_rpc, mock_filter):
         x_rpc = mock_rpc.return_value
         recover_action = {'operation': 'REBUILD'}
-        endpoint = hm.NovaNotificationEndpoint('PROJECT', 'CLUSTER_ID',
-                                               recover_action)
+        endpoint = nova_endpoint.NovaNotificationEndpoint(
+            'PROJECT', 'CLUSTER_ID', recover_action
+        )
         ctx = mock.Mock()
         payload = {'metadata': {'cluster_id': 'FOOBAR'}}
         metadata = {'timestamp': 'TIMESTAMP'}
@@ -169,12 +174,13 @@ class TestNovaNotificationEndpoint(base.SenlinTestCase):
         self.assertIsNone(res)
         self.assertEqual(0, x_rpc.node_recover.call_count)
 
-    @mock.patch('senlin.rpc.client.EngineClient')
+    @mock.patch('senlin.rpc.client.get_engine_client')
     def test_info_event_type_not_interested(self, mock_rpc, mock_filter):
         x_rpc = mock_rpc.return_value
         recover_action = {'operation': 'REBUILD'}
-        endpoint = hm.NovaNotificationEndpoint('PROJECT', 'CLUSTER_ID',
-                                               recover_action)
+        endpoint = nova_endpoint.NovaNotificationEndpoint(
+            'PROJECT', 'CLUSTER_ID', recover_action
+        )
         ctx = mock.Mock()
         payload = {'metadata': {'cluster_id': 'CLUSTER_ID'}}
         metadata = {'timestamp': 'TIMESTAMP'}
@@ -185,12 +191,13 @@ class TestNovaNotificationEndpoint(base.SenlinTestCase):
         self.assertIsNone(res)
         self.assertEqual(0, x_rpc.node_recover.call_count)
 
-    @mock.patch('senlin.rpc.client.EngineClient')
+    @mock.patch('senlin.rpc.client.get_engine_client')
     def test_info_no_node_id(self, mock_rpc, mock_filter):
         x_rpc = mock_rpc.return_value
         recover_action = {'operation': 'REBUILD'}
-        endpoint = hm.NovaNotificationEndpoint('PROJECT', 'CLUSTER_ID',
-                                               recover_action)
+        endpoint = nova_endpoint.NovaNotificationEndpoint(
+            'PROJECT', 'CLUSTER_ID', recover_action
+        )
         ctx = mock.Mock()
         payload = {'metadata': {'cluster_id': 'CLUSTER_ID'}}
         metadata = {'timestamp': 'TIMESTAMP'}
@@ -202,12 +209,13 @@ class TestNovaNotificationEndpoint(base.SenlinTestCase):
         self.assertEqual(0, x_rpc.node_recover.call_count)
 
     @mock.patch.object(context.RequestContext, 'from_dict')
-    @mock.patch('senlin.rpc.client.EngineClient')
+    @mock.patch('senlin.rpc.client.get_engine_client')
     def test_info_default_values(self, mock_rpc, mock_context, mock_filter):
         x_rpc = mock_rpc.return_value
         recover_action = {'operation': 'REBUILD'}
-        endpoint = hm.NovaNotificationEndpoint('PROJECT', 'CLUSTER_ID',
-                                               recover_action)
+        endpoint = nova_endpoint.NovaNotificationEndpoint(
+            'PROJECT', 'CLUSTER_ID', recover_action
+        )
         ctx = mock.Mock()
         payload = {
             'metadata': {
@@ -239,216 +247,16 @@ class TestNovaNotificationEndpoint(base.SenlinTestCase):
         self.assertEqual(expected_params, req.params)
 
 
-@mock.patch('oslo_messaging.NotificationFilter')
-class TestHeatNotificationEndpoint(base.SenlinTestCase):
-
-    @mock.patch('senlin.rpc.client.EngineClient')
-    def test_init(self, mock_rpc, mock_filter):
-        x_filter = mock_filter.return_value
-        event_map = {
-            'orchestration.stack.delete.end': 'DELETE',
-        }
-        recover_action = {'operation': 'REBUILD'}
-        obj = hm.HeatNotificationEndpoint('PROJECT', 'CLUSTER', recover_action)
-
-        mock_filter.assert_called_once_with(
-            publisher_id='^orchestration.*',
-            event_type='^orchestration\.stack\..*',
-            context={'project_id': '^PROJECT$'})
-        mock_rpc.assert_called_once_with()
-        self.assertEqual(x_filter, obj.filter_rule)
-        self.assertEqual(mock_rpc.return_value, obj.rpc)
-        for e in event_map:
-            self.assertIn(e, obj.STACK_FAILURE_EVENTS)
-            self.assertEqual(event_map[e], obj.STACK_FAILURE_EVENTS[e])
-        self.assertEqual('PROJECT', obj.project_id)
-        self.assertEqual('CLUSTER', obj.cluster_id)
-
-    @mock.patch.object(context.RequestContext, 'from_dict')
-    @mock.patch('senlin.rpc.client.EngineClient')
-    def test_info(self, mock_rpc, mock_context, mock_filter):
-        x_rpc = mock_rpc.return_value
-        recover_action = {'operation': 'REBUILD'}
-        endpoint = hm.HeatNotificationEndpoint('PROJECT', 'CLUSTER_ID',
-                                               recover_action)
-        ctx = mock.Mock()
-        payload = {
-            'tags': {
-                'cluster_id=CLUSTER_ID',
-                'cluster_node_id=FAKE_NODE',
-                'cluster_node_index=123',
-            },
-            'stack_identity': 'PHYSICAL_ID',
-            'user_identity': 'USER',
-            'state': 'DELETE_COMPLETE',
-        }
-        metadata = {'timestamp': 'TIMESTAMP'}
-        call_ctx = mock.Mock()
-        mock_context.return_value = call_ctx
-
-        res = endpoint.info(ctx, 'PUBLISHER', 'orchestration.stack.delete.end',
-                            payload, metadata)
-
-        self.assertIsNone(res)
-        x_rpc.call.assert_called_once_with(call_ctx, 'node_recover', mock.ANY)
-        req = x_rpc.call.call_args[0][2]
-        self.assertIsInstance(req, objects.NodeRecoverRequest)
-        self.assertEqual('FAKE_NODE', req.identity)
-        expected_params = {
-            'event': 'DELETE',
-            'state': 'DELETE_COMPLETE',
-            'stack_id': 'PHYSICAL_ID',
-            'timestamp': 'TIMESTAMP',
-            'publisher': 'PUBLISHER',
-            'operation': 'REBUILD',
-        }
-        self.assertEqual(expected_params, req.params)
-
-    @mock.patch('senlin.rpc.client.EngineClient')
-    def test_info_event_type_not_interested(self, mock_rpc, mock_filter):
-        x_rpc = mock_rpc.return_value
-        recover_action = {'operation': 'REBUILD'}
-        endpoint = hm.HeatNotificationEndpoint('PROJECT', 'CLUSTER_ID',
-                                               recover_action)
-        ctx = mock.Mock()
-        payload = {'tags': {'cluster_id': 'CLUSTER_ID'}}
-        metadata = {'timestamp': 'TIMESTAMP'}
-
-        res = endpoint.info(ctx, 'PUBLISHER',
-                            'orchestration.stack.create.start',
-                            payload, metadata)
-
-        self.assertIsNone(res)
-        self.assertEqual(0, x_rpc.node_recover.call_count)
-
-    @mock.patch('senlin.rpc.client.EngineClient')
-    def test_info_no_tag(self, mock_rpc, mock_filter):
-        x_rpc = mock_rpc.return_value
-        recover_action = {'operation': 'REBUILD'}
-        endpoint = hm.HeatNotificationEndpoint('PROJECT', 'CLUSTER_ID',
-                                               recover_action)
-        ctx = mock.Mock()
-        payload = {'tags': None}
-        metadata = {'timestamp': 'TIMESTAMP'}
-
-        res = endpoint.info(ctx, 'PUBLISHER', 'orchestration.stack.delete.end',
-                            payload, metadata)
-
-        self.assertIsNone(res)
-        self.assertEqual(0, x_rpc.node_recover.call_count)
-
-    @mock.patch('senlin.rpc.client.EngineClient')
-    def test_info_empty_tag(self, mock_rpc, mock_filter):
-        x_rpc = mock_rpc.return_value
-        recover_action = {'operation': 'REBUILD'}
-        endpoint = hm.HeatNotificationEndpoint('PROJECT', 'CLUSTER_ID',
-                                               recover_action)
-        ctx = mock.Mock()
-        payload = {'tags': []}
-        metadata = {'timestamp': 'TIMESTAMP'}
-
-        res = endpoint.info(ctx, 'PUBLISHER', 'orchestration.stack.delete.end',
-                            payload, metadata)
-
-        self.assertIsNone(res)
-        self.assertEqual(0, x_rpc.node_recover.call_count)
-
-    @mock.patch('senlin.rpc.client.EngineClient')
-    def test_info_no_cluster_in_tag(self, mock_rpc, mock_filter):
-        x_rpc = mock_rpc.return_value
-        recover_action = {'operation': 'REBUILD'}
-        endpoint = hm.HeatNotificationEndpoint('PROJECT', 'CLUSTER_ID',
-                                               recover_action)
-        ctx = mock.Mock()
-        payload = {'tags': ['foo', 'bar']}
-        metadata = {'timestamp': 'TIMESTAMP'}
-
-        res = endpoint.info(ctx, 'PUBLISHER', 'orchestration.stack.delete.end',
-                            payload, metadata)
-
-        self.assertIsNone(res)
-        self.assertEqual(0, x_rpc.node_recover.call_count)
-
-    @mock.patch('senlin.rpc.client.EngineClient')
-    def test_info_no_node_in_tag(self, mock_rpc, mock_filter):
-        x_rpc = mock_rpc.return_value
-        recover_action = {'operation': 'REBUILD'}
-        endpoint = hm.HeatNotificationEndpoint('PROJECT', 'CLUSTER_ID',
-                                               recover_action)
-        ctx = mock.Mock()
-        payload = {'tags': ['cluster_id=C1ID']}
-        metadata = {'timestamp': 'TIMESTAMP'}
-
-        res = endpoint.info(ctx, 'PUBLISHER', 'orchestration.stack.delete.end',
-                            payload, metadata)
-
-        self.assertIsNone(res)
-        self.assertEqual(0, x_rpc.node_recover.call_count)
-
-    @mock.patch('senlin.rpc.client.EngineClient')
-    def test_info_cluster_id_not_match(self, mock_rpc, mock_filter):
-        x_rpc = mock_rpc.return_value
-        recover_action = {'operation': 'REBUILD'}
-        endpoint = hm.HeatNotificationEndpoint('PROJECT', 'CLUSTER_ID',
-                                               recover_action)
-        ctx = mock.Mock()
-        payload = {'tags': ['cluster_id=FOOBAR', 'cluster_node_id=N2']}
-        metadata = {'timestamp': 'TIMESTAMP'}
-
-        res = endpoint.info(ctx, 'PUBLISHER', 'orchestration.stack.delete.end',
-                            payload, metadata)
-
-        self.assertIsNone(res)
-        self.assertEqual(0, x_rpc.node_recover.call_count)
-
-    @mock.patch.object(context.RequestContext, 'from_dict')
-    @mock.patch('senlin.rpc.client.EngineClient')
-    def test_info_default_values(self, mock_rpc, mock_context, mock_filter):
-        x_rpc = mock_rpc.return_value
-        recover_action = {'operation': 'REBUILD'}
-        endpoint = hm.HeatNotificationEndpoint('PROJECT', 'CLUSTER_ID',
-                                               recover_action)
-        ctx = mock.Mock()
-        payload = {
-            'tags': [
-                'cluster_id=CLUSTER_ID',
-                'cluster_node_id=NODE_ID'
-            ],
-            'user_identity': 'USER',
-        }
-        metadata = {'timestamp': 'TIMESTAMP'}
-        call_ctx = mock.Mock()
-        mock_context.return_value = call_ctx
-
-        res = endpoint.info(ctx, 'PUBLISHER', 'orchestration.stack.delete.end',
-                            payload, metadata)
-
-        self.assertIsNone(res)
-        x_rpc.call.assert_called_once_with(call_ctx, 'node_recover', mock.ANY)
-        req = x_rpc.call.call_args[0][2]
-        self.assertIsInstance(req, objects.NodeRecoverRequest)
-        self.assertEqual('NODE_ID', req.identity)
-        expected_params = {
-            'event': 'DELETE',
-            'state': 'Unknown',
-            'stack_id': 'Unknown',
-            'timestamp': 'TIMESTAMP',
-            'publisher': 'PUBLISHER',
-            'operation': 'REBUILD',
-        }
-        self.assertEqual(expected_params, req.params)
-
-
-@mock.patch('senlin.engine.health_manager.HeatNotificationEndpoint')
-@mock.patch('senlin.engine.health_manager.NovaNotificationEndpoint')
-@mock.patch('oslo_messaging.Target')
+@mock.patch(
+    'senlin.engine.notifications.heat_endpoint.HeatNotificationEndpoint')
+@mock.patch(
+    'senlin.engine.notifications.nova_endpoint.NovaNotificationEndpoint')
 @mock.patch('oslo_messaging.get_notification_transport')
 @mock.patch('oslo_messaging.get_notification_listener')
 class TestListenerProc(base.SenlinTestCase):
 
     def test_listener_proc_nova(self, mock_listener, mock_transport,
-                                mock_target, mock_novaendpoint,
-                                mock_heatendpoint):
+                                mock_novaendpoint, mock_heatendpoint):
         cfg.CONF.set_override('nova_control_exchange', 'FAKE_EXCHANGE',
                               group='health_manager')
 
@@ -456,8 +264,6 @@ class TestListenerProc(base.SenlinTestCase):
         mock_listener.return_value = x_listener
         x_transport = mock.Mock()
         mock_transport.return_value = x_transport
-        x_target = mock.Mock()
-        mock_target.return_value = x_target
         x_endpoint = mock.Mock()
         mock_novaendpoint.return_value = x_endpoint
 
@@ -467,24 +273,19 @@ class TestListenerProc(base.SenlinTestCase):
 
         self.assertIsNone(res)
         mock_transport.assert_called_once_with(cfg.CONF)
-        mock_target.assert_called_once_with(topic="versioned_notifications",
-                                            exchange='FAKE_EXCHANGE')
         mock_novaendpoint.assert_called_once_with('PROJECT_ID', 'CLUSTER_ID',
                                                   recover_action)
         mock_listener.assert_called_once_with(
-            x_transport, [x_target], [x_endpoint],
+            x_transport, [mock_novaendpoint().target], [x_endpoint],
             executor='threading', pool="senlin-listeners")
         x_listener.start.assert_called_once_with()
 
     def test_listener_proc_heat(self, mock_listener, mock_transport,
-                                mock_target, mock_novaendpoint,
-                                mock_heatendpoint):
+                                mock_novaendpoint, mock_heatendpoint):
         x_listener = mock.Mock()
         mock_listener.return_value = x_listener
         x_transport = mock.Mock()
         mock_transport.return_value = x_transport
-        x_target = mock.Mock()
-        mock_target.return_value = x_target
         x_endpoint = mock.Mock()
         mock_heatendpoint.return_value = x_endpoint
 
@@ -494,12 +295,10 @@ class TestListenerProc(base.SenlinTestCase):
 
         self.assertIsNone(res)
         mock_transport.assert_called_once_with(cfg.CONF)
-        mock_target.assert_called_once_with(topic="notifications",
-                                            exchange='heat')
         mock_heatendpoint.assert_called_once_with('PROJECT_ID', 'CLUSTER_ID',
                                                   recover_action)
         mock_listener.assert_called_once_with(
-            x_transport, [x_target], [x_endpoint],
+            x_transport, [mock_heatendpoint().target], [x_endpoint],
             executor='threading', pool="senlin-listeners")
         x_listener.start.assert_called_once_with()
 
@@ -957,7 +756,7 @@ class TestHealthCheck(base.SenlinTestCase):
         super(TestHealthCheck, self).setUp()
         ctx = mock.Mock()
         self.fake_rpc = mock.Mock()
-        with mock.patch.object(rpc_client, 'EngineClient',
+        with mock.patch.object(rpc_client, 'get_engine_client',
                                return_value=self.fake_rpc):
             self.hc = hm.HealthCheck(
                 ctx=ctx,
@@ -1720,106 +1519,3 @@ class TestRuntimeHealthRegistry(base.SenlinTestCase):
         self.mock_tg.timer_done.assert_not_called()
         self.mock_tg.thread_done.assert_called_once_with(fake_listener)
         self.assertIsNone(mock_entry.listener)
-
-
-class TestHealthManager(base.SenlinTestCase):
-
-    def setUp(self):
-        super(TestHealthManager, self).setUp()
-
-        mock_eng = mock.Mock()
-        mock_eng.engine_id = 'ENGINE_ID'
-        topic = consts.HEALTH_MANAGER_TOPIC
-        version = consts.RPC_API_VERSION
-        self.hm = hm.HealthManager(mock_eng, topic, version)
-
-    def test_init(self):
-        self.assertEqual('ENGINE_ID', self.hm.engine_id)
-        self.assertIsNotNone(self.hm.TG)
-        self.assertIsNotNone(self.hm.rpc_client)
-        self.assertEqual(consts.HEALTH_MANAGER_TOPIC, self.hm.topic)
-        self.assertEqual(consts.RPC_API_VERSION, self.hm.version)
-        self.assertEqual(0, len(self.hm.registries))
-
-    def test_task(self):
-        self.hm.health_registry = mock.Mock()
-        self.hm.task()
-        self.hm.health_registry.load_runtime_registry.assert_called_once_with()
-
-    @mock.patch('oslo_messaging.Target')
-    def test_start(self, mock_target):
-        self.hm.TG = mock.Mock()
-        target = mock.Mock()
-        mock_target.return_value = target
-        x_rpc_server = mock.Mock()
-        mock_get_rpc = self.patchobject(messaging, 'get_rpc_server',
-                                        return_value=x_rpc_server)
-        x_timer = mock.Mock()
-        mock_add_timer = self.patchobject(self.hm.TG, 'add_dynamic_timer',
-                                          return_value=x_timer)
-
-        # do it
-        self.hm.start()
-
-        # assert
-        mock_target.assert_called_once_with(server='ENGINE_ID',
-                                            topic='engine-health-mgr',
-                                            version=consts.RPC_API_VERSION)
-        mock_get_rpc.assert_called_once_with(target, self.hm)
-        x_rpc_server.start.assert_called_once_with()
-        mock_add_timer.assert_called_once_with(
-            self.hm.task, None, cfg.CONF.periodic_interval)
-
-    def test_stop(self):
-        self.hm.TG = mock.Mock()
-        self.hm.stop()
-        self.hm.TG.stop_timers.assert_called_once_with()
-
-    def test_register_cluster(self):
-        self.hm.health_registry = mock.Mock()
-        ctx = mock.Mock()
-        self.hm.register_cluster(ctx, 'CID', 60, 160, {}, True)
-        self.hm.health_registry.register_cluster.assert_called_once_with(
-            cluster_id='CID',
-            enabled=True,
-            interval=60,
-            node_update_timeout=160,
-            params={})
-
-    def test_unregister_cluster(self):
-        self.hm.health_registry = mock.Mock()
-        ctx = mock.Mock()
-        self.hm.unregister_cluster(ctx, 'CID')
-        self.hm.health_registry.unregister_cluster.assert_called_once_with(
-            'CID')
-
-    @mock.patch.object(context, 'get_admin_context')
-    @mock.patch.object(hr.HealthRegistry, 'get')
-    def test_get_manager_engine(self, mock_get, mock_ctx):
-        ctx = mock.Mock()
-        mock_ctx.return_value = ctx
-
-        registry = mock.Mock(engine_id='fake')
-        mock_get.return_value = registry
-
-        result = hm.get_manager_engine('CID')
-
-        self.assertEqual(result, 'fake')
-
-        mock_get.assert_called_once_with(ctx, 'CID')
-        self.assertTrue(mock_ctx.called)
-
-    @mock.patch.object(context, 'get_admin_context')
-    @mock.patch.object(hr.HealthRegistry, 'get')
-    def test_get_manager_engine_none(self, mock_get, mock_ctx):
-        ctx = mock.Mock()
-        mock_ctx.return_value = ctx
-
-        mock_get.return_value = None
-
-        result = hm.get_manager_engine('CID')
-
-        self.assertIsNone(result)
-
-        mock_get.assert_called_once_with(ctx, 'CID')
-        self.assertTrue(mock_ctx.called)
