@@ -13,7 +13,6 @@
 import copy
 
 import mock
-import six
 
 from senlin.common import exception as exc
 from senlin.objects import node as node_obj
@@ -182,7 +181,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
                                obj, 'NEW_NAME')
 
         self.assertEqual("Failed in updating server 'NOVA_ID': BOOM.",
-                         six.text_type(ex))
+                         str(ex))
         cc.server_update.assert_called_once_with('NOVA_ID', name='NEW_NAME')
 
     def test_update_password(self):
@@ -210,7 +209,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
                                obj, 'NEW_PASSWORD')
 
         self.assertEqual("Failed in updating server 'NOVA_ID': BOOM.",
-                         six.text_type(ex))
+                         str(ex))
         cc.server_change_password.assert_called_once_with(
             'NOVA_ID', 'NEW_PASSWORD')
 
@@ -268,7 +267,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
                                obj, new_profile)
 
         self.assertEqual("Failed in updating server 'NOVA_ID': "
-                         "Nova Error.", six.text_type(ex))
+                         "Nova Error.", str(ex))
         cc.server_metadata_update.assert_called_once_with(
             'NOVA_ID', {'fooa': 'baaar', 'cluster_node_id': 'NODE_ID'}
         )
@@ -385,7 +384,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
         cc.server_resize_revert.assert_called_once_with('NOVA_ID')
         cc.wait_for_server.assert_called_once_with('NOVA_ID', 'ACTIVE')
         self.assertEqual("Failed in updating server 'NOVA_ID': Resize "
-                         "failed.", six.text_type(ex))
+                         "failed.", str(ex))
 
     def test_update_flavor_first_wait_for_server_failed(self):
         obj = mock.Mock(physical_id='NOVA_ID')
@@ -419,7 +418,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
             mock.call('NOVA_ID', 'ACTIVE')])
         cc.server_resize_revert.assert_called_once_with('NOVA_ID')
         self.assertEqual("Failed in updating server 'NOVA_ID': "
-                         "TIMEOUT.", six.text_type(ex))
+                         "TIMEOUT.", str(ex))
 
     def test_update_flavor_resize_failed_revert_failed(self):
         obj = mock.Mock(physical_id='NOVA_ID')
@@ -452,7 +451,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
         # the wait_for_server wasn't called
         self.assertEqual(0, cc.wait_for_server.call_count)
         self.assertEqual("Failed in updating server 'NOVA_ID': "
-                         "Revert.", six.text_type(ex))
+                         "Revert.", str(ex))
 
     def test_update_flavor_confirm_failed(self):
         obj = mock.Mock(physical_id='NOVA_ID')
@@ -482,7 +481,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
         cc.server_resize_confirm.assert_called_once_with('NOVA_ID')
         cc.wait_for_server.assert_called_once_with('NOVA_ID', 'VERIFY_RESIZE')
         self.assertEqual("Failed in updating server 'NOVA_ID': Confirm.",
-                         six.text_type(ex))
+                         str(ex))
 
     def test_update_flavor_wait_confirm_failed(self):
         obj = mock.Mock(physical_id='NOVA_ID')
@@ -515,7 +514,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
             mock.call('NOVA_ID', 'ACTIVE')
         ])
         self.assertEqual("Failed in updating server 'NOVA_ID': Wait.",
-                         six.text_type(ex))
+                         str(ex))
 
     def test_update_image(self):
         profile = server.ServerProfile('t', self.spec)
@@ -555,7 +554,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
 
         msg = ("Failed in updating server 'NOVA_ID': Updating Nova server"
                " with image set to None is not supported by Nova.")
-        self.assertEqual(msg, six.text_type(ex))
+        self.assertEqual(msg, str(ex))
 
     def test_update_image_new_image_invalid(self):
         # NOTE: The image invalid could be caused by a non-existent image or
@@ -575,7 +574,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
                                obj, new_profile, 'new_name', 'new_pass')
 
         msg = ("Failed in updating server 'NOVA_ID': BAD.")
-        self.assertEqual(msg, six.text_type(ex))
+        self.assertEqual(msg, str(ex))
         mock_check.assert_called_once_with(obj, 'new_image', reason='update')
 
     def test_update_image_old_image_invalid(self):
@@ -603,7 +602,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
                                obj, new_profile, 'new_name', 'new_pass')
 
         msg = ("Failed in updating server 'NOVA_ID': BAD.")
-        self.assertEqual(msg, six.text_type(ex))
+        self.assertEqual(msg, str(ex))
         mock_check.assert_has_calls([
             mock.call(obj, 'new_image', reason='update'),
         ])
@@ -655,7 +654,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
                                obj, new_profile, 'new_name', 'new_pass')
 
         self.assertEqual("Failed in updating server 'NOVA_ID': DRIVER.",
-                         six.text_type(ex))
+                         str(ex))
         mock_check.assert_called_once_with(obj, 'new_image', reason='update')
         cc.server_get.assert_called_once_with('NOVA_ID')
 
@@ -706,7 +705,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
                                obj, new_profile, 'new_name', 'new_pass')
 
         self.assertEqual("Failed in updating server 'NOVA_ID': FAILED.",
-                         six.text_type(ex))
+                         str(ex))
         mock_check.assert_has_calls([
             mock.call(obj, 'new_image', reason='update'),
         ])
@@ -736,7 +735,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
                                obj, new_profile, 'new_name', 'new_pass')
 
         self.assertEqual("Failed in updating server 'NOVA_ID': TIMEOUT.",
-                         six.text_type(ex))
+                         str(ex))
         mock_check.assert_has_calls([
             mock.call(obj, 'new_image', reason='update'),
         ])
@@ -798,9 +797,9 @@ class TestNovaServerUpdate(base.SenlinTestCase):
         mock_validate.assert_has_calls(validation_calls)
         mock_get_port.assert_called_with(obj, {'port': 'port4'})
         create_calls = [
-            mock.call(server_obj, port_id='port1_id'),
-            mock.call(server_obj, port_id='port2_id'),
-            mock.call(server_obj, port_id='port4_id'),
+            mock.call(server_obj, port='port1_id'),
+            mock.call(server_obj, port='port2_id'),
+            mock.call(server_obj, port='port4_id'),
         ]
         cc.server_interface_create.assert_has_calls(create_calls)
 
@@ -819,7 +818,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
                                obj, networks)
 
         self.assertEqual("Failed in updating server 'NOVA_ID': Not valid.",
-                         six.text_type(ex))
+                         str(ex))
         cc.server_get.assert_called_once_with('NOVA_ID')
         self.assertEqual(0, profile._create_ports_from_properties.call_count)
 
@@ -841,7 +840,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
                                obj, networks)
 
         self.assertEqual("Failed in updating server 'NOVA_ID': Driver error.",
-                         six.text_type(ex))
+                         str(ex))
         cc.server_get.assert_called_once_with('NOVA_ID')
         mock_validate.assert_called_once_with(obj, networks[0], 'update')
         self.assertEqual(0, cc.server_interface_create.call_count)
@@ -913,7 +912,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
                                obj, networks)
 
         self.assertEqual("Failed in updating server 'NOVA_ID': BANG.",
-                         six.text_type(ex))
+                         str(ex))
         cc.server_interface_delete.assert_called_once_with('port1', 'NOVA_ID')
 
     @mock.patch.object(server.ServerProfile, '_update_network_remove_port')
@@ -1056,7 +1055,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
                                obj, new_profile)
 
         self.assertEqual("Failed in updating server 'NOVA_ID': BANG.",
-                         six.text_type(ex))
+                         str(ex))
         mock_check_name.assert_called_once_with(obj, new_profile)
         mock_check_password.assert_called_once_with(obj, new_profile)
         mock_update_image.assert_called_once_with(
@@ -1126,7 +1125,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
         mock_update_image.assert_called_with(
             obj, new_profile, 'OLD_NAME', 'OLD_PASS')
         self.assertEqual("Failed in updating server 'NOVA_ID': "
-                         "Image Not Found.", six.text_type(ex))
+                         "Image Not Found.", str(ex))
 
     @mock.patch.object(server.ServerProfile, '_update_flavor')
     def test_do_update_update_flavor_succeeded(self, mock_update_flavor):
@@ -1173,7 +1172,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
         mock_update_flavor.assert_called_with(obj, new_profile)
         self.assertEqual("Failed in updating server 'NOVA_ID': "
                          "Flavor Not Found.",
-                         six.text_type(ex))
+                         str(ex))
         gc.image_find.assert_called_with('FAKE_IMAGE', False)
 
     @mock.patch.object(server.ServerProfile, '_update_flavor')
@@ -1239,7 +1238,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
                                obj, new_profile)
 
         self.assertEqual("Failed in updating server 'NOVA_ID': BOOM.",
-                         six.text_type(ex))
+                         str(ex))
         mock_check_name.assert_called_once_with(obj, new_profile)
         mock_check_password.assert_called_once_with(obj, new_profile)
         mock_update_image.assert_called_once_with(
