@@ -11,7 +11,6 @@
 # under the License.
 
 import mock
-import six
 
 from senlin.common import exception as exc
 from senlin.profiles.os.nova import server
@@ -117,7 +116,7 @@ class TestAvailabilityZoneValidation(base.SenlinTestCase):
             ex = self.assertRaises(self.exception,
                                    self.profile._validate_az,
                                    node, 'FAKE_AZ', self.reason)
-            self.assertEqual(self.message, six.text_type(ex))
+            self.assertEqual(self.message, str(ex))
 
         self.cc.validate_azs.assert_called_once_with(['FAKE_AZ'])
 
@@ -233,7 +232,7 @@ class TestFlavorValidation(base.SenlinTestCase):
             ex = self.assertRaises(self.exception,
                                    self.profile._validate_flavor,
                                    node, flavor, self.reason)
-            self.assertEqual(self.message, six.text_type(ex))
+            self.assertEqual(self.message, str(ex))
 
         self.cc.flavor_find.assert_called_once_with(flavor, False)
 
@@ -310,11 +309,13 @@ class TestImageValidation(base.SenlinTestCase):
         super(TestImageValidation, self).setUp()
 
         self.cc = mock.Mock()
+        self.gc = mock.Mock()
         self.profile = server.ServerProfile('t', spec)
         self.profile._computeclient = self.cc
+        self.profile._glanceclient = self.gc
 
     def test_validation(self):
-        self.cc.image_find.side_effect = self.validate_result
+        self.gc.image_find.side_effect = self.validate_result
         node = mock.Mock(id='NODE_ID', physical_id='NOVA_ID')
         image = 'IMAGE'
 
@@ -326,9 +327,109 @@ class TestImageValidation(base.SenlinTestCase):
             ex = self.assertRaises(self.exception,
                                    self.profile._validate_image,
                                    node, image, self.reason)
-            self.assertEqual(self.message, six.text_type(ex))
+            self.assertEqual(self.message, str(ex))
 
-        self.cc.image_find.assert_called_once_with(image, False)
+        self.gc.image_find.assert_called_once_with(image, False)
+
+
+class TestVolumeValidation(base.SenlinTestCase):
+
+    scenarios = [
+        ('validate:success', dict(
+            reason=None,
+            success=True,
+            validate_result=[mock.Mock(id='VOLUME_ID', status='available')],
+            result='VOLUME_ID',
+            exception=None,
+            message='')),
+        ('validate:failure', dict(
+            reason=None,
+            success=False,
+            validate_result=[mock.Mock(id='VOLUME_ID', status='in-use')],
+            result='VOLUME_ID',
+            exception=exc.InvalidSpec,
+            message="The volume VOLUME should be in 'available' "
+                    "status but is in 'in-use' status.")),
+        ('validate:driver_failure', dict(
+            reason=None,
+            success=False,
+            validate_result=exc.InternalError(message='BANG.'),
+            result='FID',
+            exception=exc.InternalError,
+            message='BANG.')),
+        ('validate:not_found', dict(
+            reason=None,
+            success=False,
+            validate_result=exc.InternalError(code=404, message='BANG.'),
+            result='FID',
+            exception=exc.InvalidSpec,
+            message="The specified volume 'VOLUME' could not be found.")),
+        ('create:success', dict(
+            reason='create',
+            success=True,
+            validate_result=[mock.Mock(id='VOLUME_ID', status='available')],
+            result='VOLUME_ID',
+            exception=None,
+            message='')),
+        ('create:driver_failure', dict(
+            reason='create',
+            success=False,
+            validate_result=exc.InternalError(message='BANG'),
+            result='FID',
+            exception=exc.EResourceCreation,
+            message='Failed in creating server: BANG.')),
+        ('create:not_found', dict(
+            reason='create',
+            success=False,
+            validate_result=exc.InternalError(code=404, message='BANG'),
+            result='FID',
+            exception=exc.EResourceCreation,
+            message="Failed in creating server: BANG.")),
+    ]
+
+    def setUp(self):
+        super(TestVolumeValidation, self).setUp()
+        bdm_v2 = [
+            {
+                'volume_size': 1,
+                'uuid': '6ce0be68',
+                'source_type': 'volume',
+                'destination_type': 'volume',
+                'boot_index': 0,
+            },
+        ]
+
+        volume_spec = {
+            'type': 'os.nova.server',
+            'version': '1.0',
+            'properties': {
+                'flavor': 'FLAV',
+                'name': 'FAKE_SERVER_NAME',
+                'security_groups': ['HIGH_SECURITY_GROUP'],
+                'block_device_mapping_v2': bdm_v2,
+            }
+        }
+
+        self.vc = mock.Mock()
+        self.profile = server.ServerProfile('t', volume_spec)
+        self.profile._block_storageclient = self.vc
+
+    def test_validation(self):
+        self.vc.volume_get.side_effect = self.validate_result
+        node = mock.Mock(id='NODE_ID', physical_id='NOVA_ID')
+        volume = 'VOLUME'
+
+        if self.success:
+            res = self.profile._validate_volume(node, volume, self.reason)
+            self.assertIsNotNone(res)
+            self.assertEqual(self.result, res.id)
+        else:
+            ex = self.assertRaises(self.exception,
+                                   self.profile._validate_volume,
+                                   node, volume, self.reason)
+            self.assertEqual(self.message, str(ex))
+
+        self.vc.volume_get.assert_called_once_with(volume)
 
 
 class TestKeypairValidation(base.SenlinTestCase):
@@ -419,7 +520,7 @@ class TestKeypairValidation(base.SenlinTestCase):
             ex = self.assertRaises(self.exception,
                                    self.profile._validate_keypair,
                                    node, key, self.reason)
-            self.assertEqual(self.message, six.text_type(ex))
+            self.assertEqual(self.message, str(ex))
 
         self.cc.keypair_find.assert_called_once_with(key, False)
 
@@ -794,7 +895,7 @@ class TestNetworkValidation(base.SenlinTestCase):
             ex = self.assertRaises(self.exception,
                                    self.profile._validate_network,
                                    obj, self.inputs, self.reason)
-            self.assertEqual(self.message, six.text_type(ex))
+            self.assertEqual(self.message, str(ex))
 
         if self.net_result:
             self.nc.network_get.assert_called_with('NET')
